# capsrv [![capsrv](https://github.com/InnovAnon-Inc/capsrv/actions/workflows/pkgrel.yml/badge.svg)](https://github.com/InnovAnon-Inc/capsrv/actions/workflows/pkgrel.yml)
Simple NCat Server to Receive and Sort AiroDump-NG .cap Files
==========

[![License Summary](https://img.shields.io/github/license/InnovAnon-Inc/capsrv?color=%23FF1100&label=Free%20Code%20for%20a%20Free%20World%21&logo=InnovAnon%2C%20Inc.&logoColor=%23FF1133&style=plastic)](https://tldrlegal.com/license/unlicense#summary)
[![Latest Release](https://img.shields.io/github/commits-since/InnovAnon-Inc/capsrv/latest?color=%23FF1100&include_prereleases&logo=InnovAnon%2C%20Inc.&logoColor=%23FF1133&style=plastic)](https://github.com/InnovAnon-Inc/capsrv/releases/latest)
[![Lines of Code](https://tokei.rs/b1/github/InnovAnon-Inc/capsrv?category=code&color=FF1100&logo=InnovAnon-Inc&logoColor=FF1133&style=plastic)](https://github.com/InnovAnon-Inc/capsrv)
[![Repo Size](https://img.shields.io/github/repo-size/InnovAnon-Inc/capsrv?color=%23FF1100&logo=InnovAnon%2C%20Inc.&logoColor=%23FF1133&style=plastic)](https://github.com/InnovAnon-Inc/capsrv)
[![CodeFactor Grade](https://img.shields.io/codefactor/grade/github/InnovAnon-Inc/capsrv?color=FF1100&logo=InnovAnon-Inc&logoColor=FF1133&style=plastic)](https://www.codefactor.io/repository/github/InnovAnon-Inc/capsrv)

![Dependent repos (via libraries.io)](https://img.shields.io/librariesio/dependent-repos/pypi/capsrv?color=FF1100&style=plastic)
![Libraries.io dependency status for latest release](https://img.shields.io/librariesio/release/pypi/capsrv?color=FF1100&style=plastic)
![Libraries.io SourceRank](https://img.shields.io/librariesio/sourcerank/pypi/capsrv?style=plastic)
![Libraries.io dependency status for GitHub repo](https://img.shields.io/librariesio/github/InnovAnon-Inc/capsrv?color=FF1100&logoColor=FF1133&style=plastic)

[![Tip Me via PayPal](https://img.shields.io/badge/paypal-donate-FF1100.svg?logo=paypal&logoColor=FF1133&style=plastic)](https://www.paypal.me/InnovAnon)

----------

Automates, centralizes and dedeplicates common operation:
determine viable targets in .cap files.

# InnovAnon, Inc. Proprietary (Innovations Anonymous)
Free Code for a Free World!
==========
![Corporate Logo](https://innovanon-inc.github.io/assets/images/logo.gif)

